@@ -8,6 +8,22 @@ from cli_helpers.compat import (text_type, int_types, float_types,
                                 HAS_PYGMENTS, Terminal256Formatter, StringIO)
 
 
+def truncate_string(data, headers, max_field_width=None, **_):
+    """Truncate very long strings. Only needed for tabular
+    representation, because trying to tabulate very long data
+    is problematic in terms of performance, and does not make any
+    sense visually.
+
+    :param iterable data: An :term:`iterable` (e.g. list) of rows.
+    :param iterable headers: The column headers.
+    :param int max_field_width: Width to truncate field for display
+    :return: The processed data and headers.
+    :rtype: tuple
+    """
+    return (([utils.truncate_string(v, max_field_width) for v in row] for row in data),
+            [utils.truncate_string(h, max_field_width) for h in headers])
+
+
 def convert_to_string(data, headers, **_):
     """Convert all *data* and *headers* to strings.
 
@@ -40,6 +56,21 @@ def override_missing_value(data, headers, missing_value='', **_):
             headers)
 
 
+def override_tab_value(data, headers, new_value='    ', **_):
+    """Override tab values in the *data* with *new_value*.
+
+    :param iterable data: An :term:`iterable` (e.g. list) of rows.
+    :param iterable headers: The column headers.
+    :param new_value: The new value to use for tab.
+    :return: The processed data and headers.
+    :rtype: tuple
+
+    """
+    return (([v.replace('\t', new_value) if isinstance(v, text_type) else v
+              for v in row] for row in data),
+            headers)
+
+
 def bytes_to_string(data, headers, **_):
     """Convert all *data* and *headers* bytes to strings.
 
